
Overview
===========


:Title: 
:Nickname: D8C3
:Summary: 
:SubChallenges: 
:Synapse page: https://www.synapse.org/#!Synapse:synXXXXXXX


.. contents::


Scoring
---------

::

    from dreamtools import D8C3
    s = D8C3()
    filename = s.download_template() 
    s.score(filename) 


